developerscripttools.SvnCommitScript
====================================

.. inheritance-diagram:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript
   :private-bases:

.. autoclass:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.alias

.. autoattribute:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.argument_parser

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.formatted_help

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.formatted_usage

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.formatted_version

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.long_description

.. autoattribute:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.program_name

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.scripting_group

.. autoattribute:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.short_description

.. autoattribute:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.version

Methods
-------

.. automethod:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.process_args

.. automethod:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.setup_argument_parser

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.__call__

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. automethod:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.SvnCommitScript.SvnCommitScript.SvnCommitScript.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
